export default class AddContentSourceStepComponent {
    workflow: any;

    static config = {
        selector: 'addContentSourceStep',
        template: `
            <div layout="column">
            <div>{{$ctrl.AddContentTranslate.get('add-content-workflow__source-step-label')}}</div>
                <md-input-container md-is-error="$ctrl.workflow.hasError('urls')" md-no-resize="true">
                    <textarea id="urlsTextArea" class="add-content-source-step__textarea-input" name="urls" ng-model="$ctrl.workflow.urls" ng-disabled="$ctrl.workflow.loading" wrap="off" rows="10" md-no-resize md-autofocus></textarea>
                    <div class="md-errors-spacer"></div>
                    <div ng-messages="$ctrl.workflow.validationErrors">
                        <div ng-message="urls">{{$ctrl.translateTooManyUrlsMessage()}}</div>
                    </div>
                </md-input-container>
            </div>
        `,
        controller: AddContentSourceStepComponent,
        bindings: {
            workflow: '<'
        }
    };

    /*@ngInject*/
    constructor(
        private AddContentTranslate,
        private AddContentTagService
    ) {

    }

    $onInit() {
        this.workflow.urls = this.workflow.urls || '';
        this.workflow.tags = []
        this.workflow.loadingTags = true;
        this.AddContentTagService.getTagsAndFilterForPersonalization(this.workflow.userObject.activeCompanyId, this.workflow.userObject._id, this.workflow.preSelectedTags)
            .then(tagList => {
                this.workflow.tags = tagList.map(tag => {
                    return {
                        display: tag.name,
                        type: 'tag',
                        id: tag.id,
                        selected: this.workflow.preSelectedTags.indexOf(tag.name) >= 0
                    }
                })
                .sort((tagA, tagB) => {
                    if(tagA.display.toLowerCase() > tagB.display.toLowerCase()) {
                        return 1;
                    }
                    if(tagA.display.toLowerCase() < tagB.display.toLowerCase()) {
                        return -1;
                    }
                    return 0;
                });
                this.workflow.loadingTags = false;
            })
            .catch(error => {
                if (error) {
                    console.error('Failed to load tags from document modification service', error);
                }
            });
    }

    translateTooManyUrlsMessage = () =>  {
        return this.AddContentTranslate.get(this.workflow.validationErrors && this.workflow.validationErrors.urls || '', {
            limit: process.env.URL_LIMIT,
            numOver: this.workflow.documents && this.workflow.documents.length - process.env.URL_LIMIT || 0
        });
    }
}
